@@ -1,40 +1,13 @@
 /*global SelectBox, interpolate*/
 // Handles related-objects functionality: lookup link for raw_id_fields
 // and Add Another links.
-
-(function($) {
-    'use strict';
-
-    function html_unescape(text) {
-        // Unescape a string that was escaped using django.utils.html.escape.
-        text = text.replace(/&lt;/g, '<');
-        text = text.replace(/&gt;/g, '>');
-        text = text.replace(/&quot;/g, '"');
-        text = text.replace(/&#39;/g, "'");
-        text = text.replace(/&amp;/g, '&');
-        return text;
-    }
-
-    // IE doesn't accept periods or dashes in the window name, but the element IDs
-    // we use to generate popup window names may contain them, therefore we map them
-    // to allowed characters in a reversible way so that we can locate the correct
-    // element when the popup window is dismissed.
-    function id_to_windowname(text) {
-        text = text.replace(/\./g, '__dot__');
-        text = text.replace(/\-/g, '__dash__');
-        return text;
-    }
-
-    function windowname_to_id(text) {
-        text = text.replace(/__dot__/g, '.');
-        text = text.replace(/__dash__/g, '-');
-        return text;
-    }
+'use strict';
+{
+    const $ = django.jQuery;
 
     function showAdminPopup(triggeringLink, name_regexp, add_popup) {
-        var name = triggeringLink.id.replace(name_regexp, '');
-        name = id_to_windowname(name);
-        var href = triggeringLink.href;
+        const name = triggeringLink.id.replace(name_regexp, '');
+        let href = triggeringLink.href;
         if (add_popup) {
             if (href.indexOf('?') === -1) {
                 href += '?_popup=1';
@@ -42,7 +15,7 @@
                 href += '&_popup=1';
             }
         }
-        var win = window.open(href, name, 'height=500,width=800,resizable=yes,scrollbars=yes');
+        const win = window.open(href, name, 'height=500,width=800,resizable=yes,scrollbars=yes');
         win.focus();
         return false;
     }
@@ -52,9 +25,9 @@
     }
 
     function dismissRelatedLookupPopup(win, chosenId) {
-        var name = windowname_to_id(win.name);
-        var elem = document.getElementById(name);
-        if (elem.className.indexOf('vManyToManyRawIdAdminField') !== -1 && elem.value) {
+        const name = win.name;
+        const elem = document.getElementById(name);
+        if (elem.classList.contains('vManyToManyRawIdAdminField') && elem.value) {
             elem.value += ',' + chosenId;
         } else {
             document.getElementById(name).value = chosenId;
@@ -67,15 +40,15 @@
     }
 
     function updateRelatedObjectLinks(triggeringLink) {
-        var $this = django.jQuery(triggeringLink);
-        var siblings = $this.nextAll('.change-related, .delete-related');
+        const $this = $(triggeringLink);
+        const siblings = $this.nextAll('.view-related, .change-related, .delete-related');
         if (!siblings.length) {
             return;
         }
-        var value = $this.val();
+        const value = $this.val();
         if (value) {
             siblings.each(function() {
-                var elm = django.jQuery(this);
+                const elm = $(this);
                 elm.attr('href', elm.attr('data-href-template').replace('__fk__', value));
             });
         } else {
@@ -84,28 +57,24 @@
     }
 
     function dismissAddRelatedObjectPopup(win, newId, newRepr) {
-        // newId and newRepr are expected to have previously been escaped by
-        // django.utils.html.escape.
-        newId = html_unescape(newId);
-        newRepr = html_unescape(newRepr);
-        var name = windowname_to_id(win.name);
-        var elem = document.getElementById(name);
+        const name = win.name;
+        const elem = document.getElementById(name);
         if (elem) {
-            var elemName = elem.nodeName.toUpperCase();
+            const elemName = elem.nodeName.toUpperCase();
             if (elemName === 'SELECT') {
                 elem.options[elem.options.length] = new Option(newRepr, newId, true, true);
             } else if (elemName === 'INPUT') {
-                if (elem.className.indexOf('vManyToManyRawIdAdminField') !== -1 && elem.value) {
+                if (elem.classList.contains('vManyToManyRawIdAdminField') && elem.value) {
                     elem.value += ',' + newId;
                 } else {
                     elem.value = newId;
                 }
             }
             // Trigger a change event to update related links if required.
-            django.jQuery(elem).trigger('change');
+            $(elem).trigger('change');
         } else {
-            var toId = name + "_to";
-            var o = new Option(newRepr, newId);
+            const toId = name + "_to";
+            const o = new Option(newRepr, newId);
             SelectBox.add_to_cache(toId, o);
             SelectBox.redisplay(toId);
         }
@@ -113,38 +82,36 @@
     }
 
     function dismissChangeRelatedObjectPopup(win, objId, newRepr, newId) {
-        objId = html_unescape(objId);
-        newRepr = html_unescape(newRepr);
-        var id = windowname_to_id(win.name).replace(/^edit_/, '');
-        var selectsSelector = interpolate('#%s, #%s_from, #%s_to', [id, id, id]);
-        var selects = django.jQuery(selectsSelector);
+        const id = win.name.replace(/^edit_/, '');
+        const selectsSelector = interpolate('#%s, #%s_from, #%s_to', [id, id, id]);
+        const selects = $(selectsSelector);
         selects.find('option').each(function() {
             if (this.value === objId) {
-                this.innerHTML = newRepr;
+                this.textContent = newRepr;
                 this.value = newId;
             }
         });
+        selects.next().find('.select2-selection__rendered').each(function() {
+            // The element can have a clear button as a child.
+            // Use the lastChild to modify only the displayed value.
+            this.lastChild.textContent = newRepr;
+            this.title = newRepr;
+        });
         win.close();
     }
 
     function dismissDeleteRelatedObjectPopup(win, objId) {
-        objId = html_unescape(objId);
-        var id = windowname_to_id(win.name).replace(/^delete_/, '');
-        var selectsSelector = interpolate('#%s, #%s_from, #%s_to', [id, id, id]);
-        var selects = django.jQuery(selectsSelector);
+        const id = win.name.replace(/^delete_/, '');
+        const selectsSelector = interpolate('#%s, #%s_from, #%s_to', [id, id, id]);
+        const selects = $(selectsSelector);
         selects.find('option').each(function() {
             if (this.value === objId) {
-                django.jQuery(this).remove();
+                $(this).remove();
             }
         }).trigger('change');
         win.close();
     }
 
-    // Global for testing purposes
-    window.html_unescape = html_unescape;
-    window.id_to_windowname = id_to_windowname;
-    window.windowname_to_id = windowname_to_id;
-
     window.showRelatedObjectLookupPopup = showRelatedObjectLookupPopup;
     window.dismissRelatedLookupPopup = dismissRelatedLookupPopup;
     window.showRelatedObjectPopup = showRelatedObjectPopup;
@@ -158,10 +125,14 @@
     window.dismissAddAnotherPopup = dismissAddRelatedObjectPopup;
 
     $(document).ready(function() {
+        $("a[data-popup-opener]").on('click', function(event) {
+            event.preventDefault();
+            opener.dismissRelatedLookupPopup(window, $(this).data("popup-opener"));
+        });
         $('body').on('click', '.related-widget-wrapper-link', function(e) {
             e.preventDefault();
             if (this.href) {
-                var event = $.Event('django:show-related', {href: this.href});
+                const event = $.Event('django:show-related', {href: this.href});
                 $(this).trigger(event);
                 if (!event.isDefaultPrevented()) {
                     showRelatedObjectPopup(this);
@@ -169,21 +140,20 @@
             }
         });
         $('body').on('change', '.related-widget-wrapper select', function(e) {
-            var event = $.Event('django:update-related');
+            const event = $.Event('django:update-related');
             $(this).trigger(event);
             if (!event.isDefaultPrevented()) {
                 updateRelatedObjectLinks(this);
             }
         });
         $('.related-widget-wrapper select').trigger('change');
-        $('.related-lookup').click(function(e) {
+        $('body').on('click', '.related-lookup', function(e) {
             e.preventDefault();
-            var event = $.Event('django:lookup-related');
+            const event = $.Event('django:lookup-related');
             $(this).trigger(event);
             if (!event.isDefaultPrevented()) {
                 showRelatedObjectLookupPopup(this);
             }
         });
     });
-
-})(django.jQuery);
+}
