@@ -190,7 +190,7 @@ class Command(BaseCommand):
         directory_created = {}
         for app_label, app_migrations in changes.items():
             if self.verbosity >= 1:
-                self.stdout.write(self.style.MIGRATE_HEADING("Migrations for '%s':" % app_label) + "\n")
+                self.stdout.write(self.style.MIGRATE_HEADING("Migrations for '%s':" % app_label))
             for migration in app_migrations:
                 # Describe the migration
                 writer = MigrationWriter(migration, self.include_header)
@@ -203,9 +203,9 @@ class Command(BaseCommand):
                         migration_string = writer.path
                     if migration_string.startswith('..'):
                         migration_string = writer.path
-                    self.stdout.write("  %s\n" % (self.style.MIGRATE_LABEL(migration_string),))
+                    self.stdout.write('  %s\n' % self.style.MIGRATE_LABEL(migration_string))
                     for operation in migration.operations:
-                        self.stdout.write("    - %s\n" % operation.describe())
+                        self.stdout.write('    - %s' % operation.describe())
                 if not self.dry_run:
                     # Write the migrations file to the disk.
                     migrations_directory = os.path.dirname(writer.path)
@@ -224,9 +224,9 @@ class Command(BaseCommand):
                     # will output the migrations to stdout rather than saving
                     # the file to the disk.
                     self.stdout.write(self.style.MIGRATE_HEADING(
-                        "Full migrations file '%s':" % writer.filename) + "\n"
-                    )
-                    self.stdout.write("%s\n" % writer.as_string())
+                        "Full migrations file '%s':" % writer.filename
+                    ))
+                    self.stdout.write(writer.as_string())
 
     def handle_merge(self, loader, conflicts):
         """
@@ -272,7 +272,7 @@ class Command(BaseCommand):
                 for migration in merge_migrations:
                     self.stdout.write(self.style.MIGRATE_LABEL("  Branch %s" % migration.name))
                     for operation in migration.merged_operations:
-                        self.stdout.write("    - %s\n" % operation.describe())
+                        self.stdout.write('    - %s' % operation.describe())
             if questioner.ask_merge(app_label):
                 # If they still want to merge it, then write out an empty
                 # file depending on the migrations needing merging.
@@ -305,6 +305,6 @@ class Command(BaseCommand):
                     # will output the merge migrations to stdout rather than saving
                     # the file to the disk.
                     self.stdout.write(self.style.MIGRATE_HEADING(
-                        "Full merge migrations file '%s':" % writer.filename) + "\n"
-                    )
-                    self.stdout.write("%s\n" % writer.as_string())
+                        "Full merge migrations file '%s':" % writer.filename
+                    ))
+                    self.stdout.write(writer.as_string())
