@@ -37,7 +37,7 @@ class ChoicesMeta(enum.EnumMeta):
     def __contains__(cls, member):
         if not isinstance(member, enum.Enum):
             # Allow non-enums to match against member values.
-            return member in {x.value for x in cls}
+            return any(x.value == member for x in cls)
         return super().__contains__(member)
 
     @property
